@@ -1235,7 +1235,10 @@
     const isChromium =
         userAgent.includes("chrome") || userAgent.includes("chromium");
     const isThunderbird = userAgent.includes("thunderbird");
-    const isFirefox = userAgent.includes("firefox") || isThunderbird;
+    const isFirefox =
+        userAgent.includes("firefox") ||
+        userAgent.includes("librewolf") ||
+        isThunderbird;
     userAgent.includes("vivaldi");
     userAgent.includes("yabrowser");
     userAgent.includes("opr") || userAgent.includes("opera");
@@ -1263,6 +1266,14 @@
         globalThis.chrome.runtime &&
         globalThis.chrome.runtime.getManifest &&
         globalThis.chrome.runtime.getManifest().manifest_version === 3;
+    (() => {
+        if (typeof document === "undefined") {
+            return false;
+        }
+        const el = document.createElement("div");
+        el.setAttribute("style", "color-scheme: dark");
+        return el.style.colorScheme === "dark";
+    })();
 
     function classes(...args) {
         const classes = [];
@@ -1360,7 +1371,7 @@
         return m(
             "button",
             {class: cls, ...attrs},
-            m("span", {class: "button__wrapper"}, children)
+            m("span", {class: "button__wrapper"}, ...children)
         );
     }
 
@@ -2312,11 +2323,15 @@
             : props.data.settings.presets.find(({urls}) =>
                   isURLInList(props.tab.url, urls)
               );
-        const theme = custom
+        let theme = custom
             ? custom.theme
             : preset
             ? preset.theme
             : props.data.settings.theme;
+        if (props.data.forcedScheme) {
+            const mode = props.data.forcedScheme === "dark" ? 1 : 0;
+            theme = {...theme, mode};
+        }
         function setTheme(config) {
             if (custom) {
                 custom.theme = {...custom.theme, ...config};
@@ -2331,6 +2346,15 @@
             } else {
                 props.actions.setTheme(config);
             }
+            if (
+                config.mode != null &&
+                props.data.settings.automation &&
+                props.data.settings.automationBehaviour === "Scheme"
+            ) {
+                props.actions.changeSettings({
+                    automation: ""
+                });
+            }
         }
         return {
             theme,
