@@ -1185,7 +1185,10 @@
     const isChromium =
         userAgent.includes("chrome") || userAgent.includes("chromium");
     const isThunderbird = userAgent.includes("thunderbird");
-    const isFirefox = userAgent.includes("firefox") || isThunderbird;
+    const isFirefox =
+        userAgent.includes("firefox") ||
+        userAgent.includes("librewolf") ||
+        isThunderbird;
     userAgent.includes("vivaldi");
     userAgent.includes("yabrowser");
     userAgent.includes("opr") || userAgent.includes("opera");
@@ -1213,6 +1216,14 @@
         globalThis.chrome.runtime &&
         globalThis.chrome.runtime.getManifest &&
         globalThis.chrome.runtime.getManifest().manifest_version === 3;
+    (() => {
+        if (typeof document === "undefined") {
+            return false;
+        }
+        const el = document.createElement("div");
+        el.setAttribute("style", "color-scheme: dark");
+        return el.style.colorScheme === "dark";
+    })();
 
     function classes(...args) {
         const classes = [];
@@ -1310,7 +1321,7 @@
         return m(
             "button",
             {class: cls, ...attrs},
-            m("span", {class: "button__wrapper"}, children)
+            m("span", {class: "button__wrapper"}, ...children)
         );
     }
 
@@ -2188,6 +2199,8 @@
         const url = new URL($url);
         if (url.host) {
             return url.host;
+        } else if (url.protocol === "file:") {
+            return url.pathname;
         }
         return url.protocol;
     }
